pub enum AuthorizerDecision {
Allow,
Ignore,
Deny,
}Available on crate feature
__sqlite-shared only.Expand description
Authorizer callback decision.
Returned by the authorizer callback to indicate whether to allow, ignore, or deny the requested operation.
Variants
Allow
Allow the operation to proceed (SQLITE_OK).
Ignore
Ignore the operation (SQLITE_IGNORE).
For Read actions, returns NULL instead of the column value.
For other actions, treats the operation as a no-op.
Deny
Deny the operation (SQLITE_DENY).
Causes the entire SQL statement to fail with an authorization error.