#[non_exhaustive]pub enum SqliteChangeOp {
Insert,
Update,
Delete,
Unknown(i32),
}Available on crate feature
__sqlite-shared only.Expand description
Identifies which kind of row change occurred.
Returned as part of SqliteChangeEvent to the callback registered via
on_update.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Insert
A row was inserted.
Update
A row was updated.
Delete
A row was deleted.
Unknown(i32)
An operation code this version of diesel does not recognize, for example one added by a future SQLite version. The inner value is the raw FFI code.