SqliteReadOnlyBlob

Struct SqliteReadOnlyBlob 

pub struct SqliteReadOnlyBlob<'conn> { /* private fields */ }
Available on crate feature __sqlite-shared only.
A read only SQLite Blob

This interface allows to incrementally read a blob from a SQLite database. Notably this type implements std::io::Read and std::io::Seek to integrate with standard Rust IO mechanisms.

You can use SqliteConnection::get_read_only_blob to get a new instance of this type

See the SQLite documentation for more details

Implementations

Source

impl SqliteReadOnlyBlob<'_>

pub fn is_empty(&self) -> bool

Is the blob storage empty

pub fn len(&self) -> usize

The size of the underlying blob in bytes

pub fn close(self) -> Result<(), Error>

Close the handle

Even if an error is returned, the handle is still closed (from the sqlite documentation):

The BLOB handle is closed unconditionally. Even if this routine returns an error code, the handle is still closed.